@@ -7,7 +7,7 @@ use Moo;
 use Math::Trig qw(:pi);
 use POSIX qw(ceil);
 
-our $VERSION = '0.0204';
+our $VERSION = '0.0205';
 
 use constant K => pi / 180;
 
@@ -198,7 +198,7 @@ Data::Turtle - Turtle Movement and State Operations
 
 =head1 VERSION
 
-version 0.0204
+version 0.0205
 
 =head1 SYNOPSIS
 
@@ -219,8 +219,10 @@ version 0.0204
 
   for my $i (1 .. 4) {
       my @line = $turtle->forward(50);
-      # if (@line) { ... # Draw it!
-      $turtle->right(90);
+      if ($turtle->pen_down) { # Draw it!
+          $turtle->right(90);
+          # ...
+      }
   }
 
 =head1 DESCRIPTION
